@@ -1,7 +1,7 @@
 package App::pause;
 
-our $DATE = '2015-04-01'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $DATE = '2015-04-04'; # DATE
+our $VERSION = '0.17'; # VERSION
 
 1;
 # ABSTRACT: A CLI for PAUSE
@@ -18,7 +18,7 @@ App::pause - A CLI for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.16 of App::pause (from Perl distribution WWW-PAUSE-Simple), released on 2015-04-01.
+This document describes version 0.17 of App::pause (from Perl distribution WWW-PAUSE-Simple), released on 2015-04-04.
 
 =head1 DESCRIPTION
 
@@ -34,15 +34,20 @@ L<pause>
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/WWW-PAUSE-Simple>.=head1 SOURCE
+Please visit the project's homepage at L<https://metacpan.org/release/WWW-PAUSE-Simple>.
 
-Source repository is at L<https://github.com/perlancar/perl-WWW-PAUSE-Simple>.=head1 BUGS
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-WWW-PAUSE-Simple>.
+
+=head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WWW-PAUSE-Simple>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
